@@ -39,7 +39,9 @@ class SystemIPSwitches:
         self.systemctl = SystemCTL()
         self.systemd = SystemD()
 
-    def switch_on(self, granular: bool = False, netclass: str = "C", interface: str = "tun+"):
+    def switch_on(
+        self, granular: bool = False, netclass: str = "C", interface: str = "tun+"
+    ):
         self.switch_flush()
         self.switch_vpn(granular=granular, netclass=netclass, interface=interface)
         self.switch_docker(granular=granular, interface=interface)
@@ -71,13 +73,15 @@ class SystemIPSwitches:
         self.systembash.run_protect()
         self.systemctl.protect_ctl_enable()
 
-    def switch_vpn(self, granular: bool = False, netclass: str = "C", interface: str = 'tun+'):
+    def switch_vpn(
+        self, granular: bool = False, netclass: str = "C", interface: str = "tun+"
+    ):
         self.systemd.openvpn(granular=granular, netclass=netclass, interface=interface)
         self.systembash.run_vpn4()
         self.systemctl.openvpn_ctl_enable()
 
     def switch_docker(self, granular: bool = False, interface: str = "tun+"):
-        self.systemd.docker(granular,interface)
+        self.systemd.docker(granular, interface)
         self.systembash.run_docker()
         self.systemctl.docker_ctl_enable()
 
@@ -236,7 +240,9 @@ class SystemD:
         ) = self.service_bash_text.synergy_off_text()
         self.systemdfiles.writebash(synergy_off_bash_filepath, synergy_off_bashtext)
 
-    def openvpn(self, granular: bool = False, netclass: str = "C", interface: str = 'tun+'):
+    def openvpn(
+        self, granular: bool = False, netclass: str = "C", interface: str = "tun+"
+    ):
         vpn_service_filepath, vpn_servicetext = self.service_unit_text.openvpn()
         if granular:
             (
@@ -247,11 +253,13 @@ class SystemD:
             (
                 vpn_bash_filepath,
                 vpn_bashtext,
-            ) = self.service_bash_text.vpnkillswitch_text(netclass=netclass, interface=interface)
+            ) = self.service_bash_text.vpnkillswitch_text(
+                netclass=netclass, interface=interface
+            )
         self.systemdfiles.writebash(vpn_bash_filepath, vpn_bashtext)
         self.systemdfiles.writeservice(vpn_service_filepath, vpn_servicetext)
 
-    def docker(self, granular: bool = False, interface: str = 'tun+'):
+    def docker(self, granular: bool = False, interface: str = "tun+"):
         docker_service_filepath, docker_servicetext = self.service_unit_text.docker()
         if granular:
             (
@@ -444,7 +452,7 @@ function escape_dots ()
 function regex_build () {
 
     escape_setting=$(escape_dots $1)
-    regex_result="^([^\S\\r\\n]|#|)+($escape_setting)([^\S\\r\\n]|[0-9]|#|[a-zA-Z])+$"
+    regex_result="^([^\S\\r\\n]|#|)+($escape_setting)([^\S\\r\\n]+=|=)([^\S\\r\\n]+[0-9]|[^\S\\r\\n]+|[0-9]|#|[a-zA-Z])+$"
     echo $regex_result
 }
 
@@ -488,12 +496,12 @@ function delete_proc_string () {
 }
 
 function disable_proc_string () {
-    proc_string_disable=$1" 1"
+    proc_string_disable=$1"=1"
     echo $proc_string_disable >> /etc/sysctl.conf
 }
 
 function enable_proc_string () {
-    proc_string_enable=$1" 0"
+    proc_string_enable=$1"=0"
     echo $proc_string_enable >> /etc/sysctl.conf
 
 }
@@ -652,7 +660,7 @@ sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.protect_bash, text
 
-    def vpnkillswitch_text(self, netclass: str = "C", interface: str = 'tun+'):
+    def vpnkillswitch_text(self, netclass: str = "C", interface: str = "tun+"):
         if netclass == "C":
             netclassip = "192.168.0.0/16"
         if netclass == "B":
@@ -753,7 +761,7 @@ sysctl_file_disable_ipv6
 """
         return self.systemdfilepaths.vpn4_bash, text
 
-    def dockerkillswitch_text(self,  interface: str = 'tun+'):
+    def dockerkillswitch_text(self, interface: str = "tun+"):
         text = f"""#!/bin/bash
 {self.bashfunctions}
 {self.procfunctions}
